@@ -61,6 +61,13 @@ bool Methods::scrStart(void)
 	TelTone::tonekey_t *key = NULL;
 	Audio::Level level = 26000;
 	bool connect_flag = false;
+	bool dg = false;
+
+	if(!name)
+	{
+		dg = true;
+		name = dial;
+	}
 
 	if(!stricmp(line->cmd, "connect"))
 	{
@@ -103,7 +110,11 @@ bool Methods::scrStart(void)
 		return true;
 	}
 
+	if(dg)
+		dial = name;
+
 	child = startDialing(dial, name, caller, display, this);
+
 	if(!child)
 	{
 		if(sym)
