@@ -314,6 +314,7 @@ public:
 		CHILD_EXPIRED,
 		CHILD_BUSY,
 		CHILD_FAX,
+		CHILD_DND,
 
 		START_SCRIPT = START_INCOMING,
 		START_SELECTED = START_OUTGOING,
@@ -407,6 +408,7 @@ public:
 		DIAL_BUSY,
 		DIAL_FAX,
 		DIAL_PAM,
+		DIAL_DND,
 
 		DIAL_MACHINE = DIAL_PAM,
 
