@@ -924,6 +924,10 @@ failed:
                 if(!scriptEvent("start:busy"))
                         error("start-busy");
                 return true;
+	case CHILD_DND:
+		if(!scriptEvent("start:dnd"))
+			error("start-dnd");
+		return true;
 	case CHILD_FAX:
 		if(!scriptEvent("start:fax"))
 			error("start-fax");
@@ -1805,6 +1809,15 @@ bool BayonneSession::stateSeize(Event *event)
 		}
 		setState(STATE_HANGUP);
 		return true;
+	case DIAL_DND:
+		seizure = CHILD_DND;
+                if(scriptEvent("call:dnd"))
+                {
+                        setRunning();
+                        return true;
+                }
+                setState(STATE_HANGUP);
+                return true;		
 	case DIAL_BUSY:
 		seizure = CHILD_BUSY;
 		if(scriptEvent("call:busy"))
