@@ -71,32 +71,13 @@ static Keydata::Define driver[] = {
 	{"offer", "4000"},	// call offer timer
         {NULL, NULL}};
 
-#ifdef	WIN32
-#define	KEYS	"/bayonne/h323"
-#else
-#define	KEYS	"/bayonne/driver/h323"
-#endif
-
 Driver Driver::h323;
 Endpoint Driver::endpoint;
 
 Driver::Driver() :
-BayonneDriver(driver, KEYS, "h323", false)
+BayonneDriver(driver, "/bayonne/driver/h323", "h323", false)
 {
 	const char *cp;
-
-#ifdef	WIN32
-	const char *env = Process::getEnv("DRIVERCONFIG");
-
-	if(env)
-		loadFile(env, "h323");
-#else
-	if(Bayonne::provision_system)
-		load("/bayonne/provision/h323");
-	else if(Bayonne::provision_user)
-		load("~bayonne/h323");
-#endif
-
 	cp = getLast("hangup");
 	if(cp)
 		hangup_timer = atoi(cp);
