@@ -326,6 +326,11 @@ void RTPStream::postAudio(Encoded encoded)
 		peer->peerAudio(encoded);
 }
 
+void RTPStream::syncAudio(void)
+{
+	oTimestamp = 0;
+}
+
 void RTPStream::peerAudio(Encoded encoded, bool linear)
 {
 	jsend = Driver::sip.jitter;
@@ -333,6 +338,12 @@ void RTPStream::peerAudio(Encoded encoded, bool linear)
 	if(tone || dtmfcount)
 		return;
 
+	if(!encoded)
+	{
+		oTimestamp = 0;
+		return;
+	}
+
 	if(linear && session->codec)
 	{
 		session->codec->encode((Linear)encoded, pbuffer, info.framecount);
@@ -374,6 +385,7 @@ void RTPStream::runActive(void)
 	DynamicPayloadFormat pf_dtmf(session->dtmf_payload, info.rate);
 	unsigned short pps = (unsigned short)(1000 / info.framing);
 	unsigned short dtmfoffset = (unsigned short)(info.rate / pps);
+	BayonneSession *joined;
 
 	jitter = Driver::sip.jitter;
 	jsend = Driver::sip.jitter;
@@ -386,6 +398,9 @@ void RTPStream::runActive(void)
 	setCancel(cancelDeferred);
         for(;;)
         {
+		if(jsend && Driver::sip.send_immediate)
+			jsend = 0;
+
 		if(!session->rtp_flag)
 		{
 			slog.debug("%s: going passive", session->getLogname());
@@ -532,6 +547,8 @@ done:
 
 				Thread::yield();
 				jitter = Driver::sip.jitter;
+				if(session->isJoined())
+					jitter = 1;
 
 				if(first)
 				{
@@ -590,6 +607,11 @@ done:
 				memset(&event, 0, sizeof(event));
 				event.id = AUDIO_STOP;
 				session->queEvent(&event);
+				joined = session->peer;
+				memset(&event, 0, sizeof(event));
+				event.id = AUDIO_SYNC;
+				if(joined && session->isJoined())
+					joined->queEvent(&event);
 				first = true;
 			}
 		}
@@ -628,6 +650,7 @@ ssize_t RTPStream::putBuffer(Encoded data, size_t len)
         result *= (getCurrentRTPClockRate() / 1000);
         if(!oTimestamp)
                 oTimestamp = getCurrentTimestamp();
+//	printf("DRIFT %ld\n", (long)oTimestamp - (long)getCurrentTimestamp());
         oTimestamp += result;
 	if(Driver::sip.send_immediate)
 		sendImmediate(oTimestamp, (const unsigned char *)data, len);
