@@ -38,31 +38,13 @@ static Keydata::Define driver[] = {
 	{"cpringback", "4000"},
         {NULL, NULL}};
 
-#ifdef	WIN32
-#define	KEYS	"/bayonne/voicetronix"
-#else
-#define	KEYS	"/bayonne/driver/voicetronix"
-#endif
-
 Driver Driver::voicetronix;
 
 Driver::Driver() :
-BayonneDriver(driver, KEYS, "voicetronix", false),
+BayonneDriver(driver, "/bayonne/driver/voicetronix", "voicetronix", false),
 Thread(atoi(getLast("priority")), atoi(getLast("stack")) * 1024)
 {
 	const char *cp;
-
-#ifdef	WIN32
-	const char *env = Process::getEnv("DRIVERCONFIG");
-
-	if(env)
-		loadFile(env, "voicetronix");
-#else
-	if(Bayonne::provision_system)
-		load("/bayonne/provision/voicetronix");
-	else if(Bayonne::provision_user)
-		load("~bayonne/voicetronix");
-#endif
 	cp = getLast("pickup");
 	if(cp)
 		pickup_timer = atol(cp);
