@@ -25,8 +25,6 @@ Runtime::Runtime() :
 ScriptRuntime()
 {
 	static ScriptInterp::Define interp[] = {
-		{"config", true, (Method)&ScriptMethods::scrNop,
-			(Check)&Checks::chkConfig},
 		{"dialtone", false, (Method)&Methods::scrTone,
 			(Check)&Checks::chkTone},
                 {"busytone", false, (Method)&Methods::scrTone,
@@ -746,31 +744,9 @@ bool Runtime::loadBinder(const char *path)
         DSO *dso;  
 
 #ifdef  WIN32
-#ifdef  HAVE_TESTING
-        if(!prefix && Bayonne::provision_test)
-#ifdef  _DEBUG
-                prefix = "DEBUG";
-#else    
-                prefix = "RELEASE";
-#endif
-#endif   
         if(!prefix)
 	 	prefix = "C:\\Program Files\\Common Files\\GNU Telephony\\Bayonne Binders";
 #else
-
-#ifdef  HAVE_TESTING
-        char prefixbuf[256];
-
-        if(!prefix && Bayonne::provision_test && !strchr(path, '/'))
-        {
-                snprintf(prefixbuf, sizeof(prefixbuf),
-                        "%s/binders/%s/.libs", SOURCE_FILES, path);
-                if(!isDir(prefixbuf))
-                        snprintf(prefixbuf, sizeof(prefixbuf),
-                                "%s/binders/%s", SOURCE_FILES, path);
-                prefix = prefixbuf;
-        }
-#endif
         if(!prefix)
                 prefix = LIBDIR_FILES;
 #endif 
